package t::ExtSite;
use strict;
use warnings;

use Bread::Board::LazyLoader::Site
    base => 't::BaseSite',
    suffix => 'bb';

1;
# vim: expandtab:shiftwidth=4:tabstop=4:softtabstop=0:textwidth=78:
